# -*- coding: utf-8 -*-
#
# Copyright (C) 2021-2022 Graz University of Technology.
#
# invenio-imoox is free software; you can redistribute it and/or modify
# it under the terms of the MIT License; see LICENSE file for more details.

"""Provides API for iMooX."""

from .ext import InvenioIMooX

__version__ = "0.1.3"

__all__ = ("__version__", "InvenioIMooX")
